@@ -535,7 +535,7 @@ sub to_app {
 }
 
 
-our $VERSION = '0.031';
+our $VERSION = '0.04';
 
 1;
 
@@ -734,6 +734,10 @@ An experimental Unity Lens object.
 
 Toshio Ito C<< <toshioito [at] cpan.org> >>
 
+=head1 REPOSITORY
+
+L<https://github.com/debug-ito/Web-Dash>
+
 =head1 LICENSE AND COPYRIGHT
 
 Copyright 2013 Toshio Ito.
